@@ -31,27 +31,9 @@
 
 Osd::Osd(ShellCorona *corona)
     : QObject(corona)
+    , m_osdPath(corona->lookAndFeelPackage().filePath("osdmainscript"))
 {
-    const QString osdPath = corona->lookAndFeelPackage().filePath("osdmainscript");
-    if (osdPath.isEmpty()) {
-        qWarning() << "Failed to load the OSD QML file file from" << osdPath;
-        return;
-    }
-
-    m_osdObject = new KDeclarative::QmlObject(this);
-    m_osdObject->setSource(QUrl::fromLocalFile(osdPath));
-    if (m_osdObject->status() != QQmlComponent::Ready) {
-        qWarning() << "Failed to load OSD QML file";
-        return;
-    }
-
-    m_timeout = m_osdObject->rootObject()->property("timeout").toInt();
-
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/kde/osdService"), this, QDBusConnection::ExportAllSlots | QDBusConnection::ExportAllSignals);
-
-    m_osdTimer = new QTimer(this);
-    m_osdTimer->setSingleShot(true);
-    connect(m_osdTimer, &QTimer::timeout, this, &Osd::hideOsd);
 }
 
 Osd::~Osd()
@@ -71,16 +53,34 @@ void Osd::keyboardBrightnessChanged(int percent)
 void Osd::volumeChanged(int percent)
 {
     QString icon;
-    if (percent >= 75) {
-        icon = QStringLiteral("audio-volume-high");
-    } else if (percent < 75 && percent >= 25) {
-        icon = QStringLiteral("audio-volume-medium");
-    } else if (percent < 25 && percent > 0) {
-        icon = QStringLiteral("audio-volume-low");
-    } else if (percent == 0) {
+    if (percent <= 0) {
         icon = QStringLiteral("audio-volume-muted");
         showText(icon, i18nc("OSD informing that the system is muted, keep short", "Audio Muted"));
         return;
+    } else if (percent <= 25) {
+        icon = QStringLiteral("audio-volume-low");
+    } else if (percent <= 75) {
+        icon = QStringLiteral("audio-volume-medium");
+    } else {
+        icon = QStringLiteral("audio-volume-high");
+    }
+
+    showProgress(icon, percent);
+}
+
+void Osd::microphoneVolumeChanged(int percent)
+{
+    QString icon;
+    if (percent <= 0) {
+        icon = QStringLiteral("microphone-sensitivity-muted");
+        showText(icon, i18nc("OSD informing that the microphone is muted, keep short", "Microphone Muted"));
+        return;
+    } else if (percent <= 25) {
+        icon = QStringLiteral("microphone-sensitivity-low");
+    } else if (percent <= 75) {
+        icon = QStringLiteral("microphone-sensitivity-medium");
+    } else {
+        icon = QStringLiteral("microphone-sensitivity-high");
     }
 
     showProgress(icon, percent);
@@ -106,14 +106,91 @@ void Osd::virtualDesktopChanged(const QString &currentVirtualDesktopName)
     showText(QString(), currentVirtualDesktopName);
 }
 
+void Osd::touchpadEnabledChanged(bool touchpadEnabled)
+{
+    if (touchpadEnabled) {
+        showText(QStringLiteral("input-touchpad-on"), i18nc("touchpad was enabled, keep short", "Touchpad On"));
+    } else {
+        showText(QStringLiteral("input-touchpad-off"), i18nc("touchpad was disabled, keep short", "Touchpad Off"));
+    }
+}
+
+void Osd::wifiEnabledChanged(bool wifiEnabled)
+{
+    if (wifiEnabled) {
+        showText(QStringLiteral("network-wireless-on"), i18nc("wireless lan was enabled, keep short", "Wifi On"));
+    } else {
+        showText(QStringLiteral("network-wireless-off"), i18nc("wireless lan was disabled, keep short", "Wifi Off"));
+    }
+}
+
+void Osd::bluetoothEnabledChanged(bool bluetoothEnabled)
+{
+    if (bluetoothEnabled) {
+        showText(QStringLiteral("preferences-system-bluetooth"), i18nc("Bluetooth was enabled, keep short", "Bluetooth On"));
+    } else {
+        showText(QStringLiteral("preferences-system-bluetooth-inactive"), i18nc("Bluetooth was disabled, keep short", "Bluetooth Off"));
+    }
+}
+
+void Osd::wwanEnabledChanged(bool wwanEnabled)
+{
+    if (wwanEnabled) {
+        showText(QStringLiteral("network-mobile-on"), i18nc("mobile internet was enabled, keep short", "Mobile Internet On"));
+    } else {
+        showText(QStringLiteral("network-mobile-off"), i18nc("mobile internet was disabled, keep short", "Mobile Internet Off"));
+    }
+}
+
+void Osd::virtualKeyboardEnabledChanged(bool virtualKeyboardEnabled)
+{
+    if (virtualKeyboardEnabled) {
+        showText(QStringLiteral("input-keyboard-virtual-on"), i18nc("on screen keyboard was enabled because physical keyboard got unplugged, keep short", "On-Screen Keyboard Activated"));
+    } else {
+        showText(QStringLiteral("input-keyboard-virtual-off"), i18nc("on screen keyboard was disabled because physical keyboard was plugged in, keep short", "On-Screen Keyboard Deactivated"));
+    }
+}
+
+bool Osd::init()
+{
+    if (m_osdObject && m_osdObject->rootObject()) {
+        return true;
+    }
+
+    if (m_osdPath.isEmpty()) {
+        return false;
+    }
+
+    if (!m_osdObject) {
+        m_osdObject = new KDeclarative::QmlObject(this);
+    }
+
+    m_osdObject->setSource(QUrl::fromLocalFile(m_osdPath));
+
+    if (m_osdObject->status() != QQmlComponent::Ready) {
+        qWarning() << "Failed to load OSD QML file" << m_osdPath;
+        return false;
+    }
+
+    m_timeout = m_osdObject->rootObject()->property("timeout").toInt();
+
+    if (!m_osdTimer) {
+        m_osdTimer = new QTimer(this);
+        m_osdTimer->setSingleShot(true);
+        connect(m_osdTimer, &QTimer::timeout, this, &Osd::hideOsd);
+    }
+
+    return true;
+}
+
 void Osd::showProgress(const QString &icon, const int percent, const QString &additionalText)
 {
-    auto *rootObject = m_osdObject->rootObject();
-    if (!rootObject) {
-        qWarning() << "Failed to load OSD QML file";
+    if (!init()) {
         return;
     }
 
+    auto *rootObject = m_osdObject->rootObject();
+
     int value = qBound(0, percent, 100);
     rootObject->setProperty("osdValue", value);
     rootObject->setProperty("osdAdditionalText", additionalText);
@@ -126,12 +203,12 @@ void Osd::showProgress(const QString &icon, const int percent, const QString &ad
 
 void Osd::showText(const QString &icon, const QString &text)
 {
-    auto *rootObject = m_osdObject->rootObject();
-    if (!rootObject) {
-        qWarning() << "Failed to load OSD QML file";
+    if (!init()) {
         return;
     }
 
+    auto *rootObject = m_osdObject->rootObject();
+
     rootObject->setProperty("showingProgress", false);
     rootObject->setProperty("osdValue", text);
     rootObject->setProperty("icon", icon);
@@ -145,9 +222,6 @@ void Osd::showOsd()
     m_osdTimer->stop();
 
     auto *rootObject = m_osdObject->rootObject();
-    if (!rootObject) {
-        return;
-    }
 
     // if our OSD understands animating the opacity, do it;
     // otherwise just show it to not break existing lnf packages
@@ -174,6 +248,5 @@ void Osd::hideOsd()
     rootObject->setProperty("visible", false);
 
     // this is needed to prevent fading from "old" values when the OSD shows up
-    rootObject->setProperty("icon", "");
     rootObject->setProperty("osdValue", 0);
 }
