@@ -114,6 +114,9 @@ ShellCorona::ShellCorona(QObject *parent)
     m_appConfigSyncTimer.setSingleShot(true);
     m_appConfigSyncTimer.setInterval(s_configSyncDelay);
     connect(&m_appConfigSyncTimer, &QTimer::timeout, this, &ShellCorona::syncAppConfig);
+    //we want our application config with screen mapping to always be in sync with the applets one, so a crash at any time will still
+    //leave containments pointing to the correct screens
+    connect(this, &Corona::configSynced, this, &ShellCorona::syncAppConfig);
 
     m_waitingPanelsTimer.setSingleShot(true);
     m_waitingPanelsTimer.setInterval(250);
@@ -624,6 +627,8 @@ void ShellCorona::load()
 
     disconnect(m_activityController, &KActivities::Controller::serviceStatusChanged, this, &ShellCorona::load);
 
+    m_screenPool->load();
+
     //TODO: a kconf_update script is needed
     QString configFileName(QStringLiteral("plasma-") + m_shell + QStringLiteral("-appletsrc"));
 
@@ -672,9 +677,9 @@ void ShellCorona::load()
             addOutput(screen);
         }
     }
-    connect(qGuiApp, &QGuiApplication::screenAdded, this, &ShellCorona::addOutput);
-    connect(qGuiApp, &QGuiApplication::primaryScreenChanged, this, &ShellCorona::primaryOutputChanged);
-    connect(qGuiApp, &QGuiApplication::screenRemoved, this, &ShellCorona::screenRemoved);
+    connect(qGuiApp, &QGuiApplication::screenAdded, this, &ShellCorona::addOutput, Qt::UniqueConnection);
+    connect(qGuiApp, &QGuiApplication::primaryScreenChanged, this, &ShellCorona::primaryOutputChanged, Qt::UniqueConnection);
+    connect(qGuiApp, &QGuiApplication::screenRemoved, this, &ShellCorona::screenRemoved, Qt::UniqueConnection);
 
     if (!m_waitingPanels.isEmpty()) {
         m_waitingPanelsTimer.start();
@@ -850,6 +855,30 @@ void ShellCorona::requestApplicationConfigSync()
 
 void ShellCorona::loadDefaultLayout()
 {
+    //pre-startup scripts
+    QString script = m_lookAndFeelPackage.filePath("layouts", QString(shell() + "-prelayout.js").toLatin1());
+    if (!script.isEmpty()) {
+          QFile file(script);
+            if (file.open(QIODevice::ReadOnly | QIODevice::Text) ) {
+                QString code = file.readAll();
+                qDebug() << "evaluating pre-startup script:" << script;
+
+                WorkspaceScripting::ScriptEngine scriptEngine(this);
+
+                connect(&scriptEngine, &WorkspaceScripting::ScriptEngine::printError, this,
+                        [](const QString &msg) {
+                            qWarning() << msg;
+                        });
+                connect(&scriptEngine, &WorkspaceScripting::ScriptEngine::print, this,
+                        [](const QString &msg) {
+                            qDebug() << msg;
+                        });
+                if (!scriptEngine.evaluateScript(code, script)) {
+                    qWarning() << "failed to initialize layout properly:" << script;
+                }
+            }
+    }
+
     //NOTE: Is important the containments already exist for each screen
     // at the moment of the script execution,the same loop in :load()
     // is executed too late
@@ -857,7 +886,7 @@ void ShellCorona::loadDefaultLayout()
         addOutput(screen);
     }
 
-    QString script = ShellManager::s_testModeLayout;
+    script = ShellManager::s_testModeLayout;
 
     if (script.isEmpty()) {
         script = m_lookAndFeelPackage.filePath("layouts", QString(shell() + "-layout.js").toLatin1());
@@ -1154,7 +1183,12 @@ Plasma::Containment *ShellCorona::createContainmentForActivity(const QString& ac
 {
     if (m_desktopContainments.contains(activity)) {
         for (Plasma::Containment *cont : m_desktopContainments.value(activity)) {
-            if (cont->screen() == screenNum && cont->activity() == activity) {
+            //in the case of a corrupt config file
+            //with multiple containments with same lastScreen
+            //it can happen two insertContainment happen for
+            //the same screen, leading to the old containment
+            //to be destroyed
+            if (!cont->destroyed() && cont->screen() == screenNum && cont->activity() == activity) {
                 return cont;
             }
         }
@@ -1808,6 +1842,7 @@ int ShellCorona::screenForContainment(const Plasma::Containment *containment) co
 //     qDebug() << "ShellCorona screenForContainment: " << containment << " Last screen is " << containment->lastScreen();
 
     for (auto screen : qGuiApp->screens()) {
+        // containment->lastScreen() == m_screenPool->id(screen->name()) to check if the lastScreen refers to a screen that exists/it's known
         if (containment->lastScreen() == m_screenPool->id(screen->name()) &&
             (containment->activity() == m_activityController->currentActivity() ||
             containment->containmentType() == Plasma::Types::PanelContainment || containment->containmentType() == Plasma::Types::CustomPanelContainment)) {
